package PJlib

  block CapacityConverter
    extends SystemDynamics.Interfaces.GenericConverter3;
  equation
    out1 = in2/(1 - in1/in3);
  end CapacityConverter;

  block ECIRConverter
    extends SystemDynamics.Interfaces.GenericConverter4;
  equation
    out1 = in2*in3*(1-in4)/(1-in1);
  end ECIRConverter;


  model TurboMachineT 
    "machine that transfers energy between a rotor and a fluid"
    import Modelica.SIunits.*;
    parameter SpecificHeatCapacity cp = 1005.45;
    parameter Temperature T0 = 298.15;
    parameter Mass K = 0.001 "pump constant";
    parameter Real epsi = 5 "compression";
    
    Thermo.Interfaces.FluidPort_a inflow annotation(Placement(transformation(
        extent = {{-110, -10},{-90, 10}}, rotation = 0)));
    Thermo.Interfaces.FluidPort_b outflow annotation(Placement(transformation(
        extent = {{90, -10},{110, 10}}, rotation = 0)));
    Modelica.Mechanics.Rotational.Interfaces.Flange_a shaft annotation(Placement(transformation(
        extent = {{-10, 90},{10, 110}}, rotation = 0)));
    Modelica.Blocks.Interfaces.RealOutput Qdot annotation(Placement(transformation(
        extent = {{-10, -110},{10, -90}}, rotation = -90)));

    AngularVelocity omega;
  equation    
    inflow.m_flow + outflow.m_flow = 0;
    inflow.H_flow = inflow.m_flow*inflow.h;
    omega = der(shaft.phi);
    outflow.h = inflow.h;
    inflow.m_flow = K*omega;
    outflow.p = epsi*inflow.p;
    Qdot = - omega*shaft.tau;
  end TurboMachineT;
  
  model PumpT 
    extends TurboMachineT;
    annotation(
      Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}})),
      Icon(coordinateSystem(
           preserveAspectRatio=true,
           extent={{-100,-100},{100,100}}),
           graphics={
	     Ellipse(extent={{-100,100},{100,-100}},
		     lineColor={0,0,0}),
             Line(points={{-77,64},{94,34}},
		  thickness=1,
		  color={0,0,0}),
             Line(points={{-77,-64},{94,-34}},
		  thickness=1,
		  color={0,0,0})
		     }));
  end PumpT;
  
  model TurbineT 
    extends TurboMachineT;
    annotation(
      Diagram(coordinateSystem(
              preserveAspectRatio=true,
              extent={{-100,-100},{100,100}})),
      Icon(coordinateSystem(
           preserveAspectRatio=true,
           extent={{-100,-100},{100,100}}),
           graphics={
             Line(points={{-100,40},{100,40},{60,-40},{-60,-40},{-100,40}},
		  thickness=1,
		  color={0,0,0}),
             Line(points={{0,40},{0,100}},
		  thickness=2,
		  color={0,0,0}),
             Line(points={{-100,0},{-80,0}},
		  thickness=1,
		  color={0,0,0}),
             Line(points={{80,0},{100,0}},
		  thickness=1,
		  color={0,0,0})
		     }));
  end TurbineT;
  
end PJlib;

